pub struct ButtonVariantColors {
pub bg: Hsla,
pub hover_bg: Hsla,
pub active_bg: Hsla,
pub text: Hsla,
pub border: Hsla,
pub text_hover: Hsla,
pub border_hover: Hsla,
}Expand description
Public design-token group for Liora button variant colors styling.
Fields
bg: HslaBase background color used in the normal state.
hover_bg: HslaBackground color used while the control is hovered.
active_bg: HslaBackground color used while the control is pressed or active.
text: HslaForeground text color used in the normal state.
border: HslaBorder color used in the normal state.
text_hover: HslaForeground text color used while the control is hovered.
border_hover: HslaBorder color used while the control is hovered.